@@ -105,7 +105,6 @@ Menu::Menu( QWidget* parent )
     safePlug( ac, "queue_manager", this );
     safePlug( ac, "equalizer", this );
     safePlug( ac, "script_manager", this );
-    safePlug( ac, "statistics", this );
 
     addSeparator();
 
@@ -355,6 +354,18 @@ RepeatAction::RepeatAction( KActionCollection *ac, QObject *parent ) :
     connect( this, SIGNAL( triggered( int ) ), The::playlistActions(), SLOT( playlistModeChanged() ) );
 }
 
+//////////////////////////////////////////////////////////////////////////////////////////
+// ReplayGainModeAction
+//////////////////////////////////////////////////////////////////////////////////////////
+ReplayGainModeAction::ReplayGainModeAction( KActionCollection *ac, QObject *parent ) :
+    SelectAction( i18n( "&Replay Gain Mode" ), &AmarokConfig::setReplayGainMode, ac, "replay_gain_mode", parent )
+{
+    setItems( QStringList() << i18nc( "State, as in, disabled", "&Off" ) << i18nc( "Item, as in, music", "&Track" )
+                            << i18n( "&Album" ) );
+    //setIcons( QStringList() << "media-playlist-replaygain-off-amarok" << "media-track-replaygain-amarok" << "media-album-replaygain-amarok" );
+    setCurrentItem( AmarokConfig::replayGainMode() );
+}
+
 //////////////////////////////////////////////////////////////////////////////////////////
 // BurnMenuAction
 //////////////////////////////////////////////////////////////////////////////////////////
